* **************************************************************************** *
* **************************************************************************** *
*           Combatting forest fires in the drylands of Sub-Saharan Africa:     *
*                Quas-experimental evidence from Burkina Faso                  *
* **************************************************************************** *
* **************************************************************************** *
/*
** PURPOSE:     Generation of Figures
** IDS VAR:	    forerstid, forestBlockID, year
** WRITTEN BY:	Tung Nguyen Huy (nghuytungi@windowslive.com)
*/
* **************************************************************************** *
* **************************************************************************** *

* Overview of all tables produced in this do file:

* Figure 1: Average precipitation per month of the year (left axis and grey bars) ...
* Figure 3: Monthly fire occurrences in the FIP and non-FIP forests ...
* Figure 4: Fire occurrence in the FIP forests in each of the seven dry months of the year ...
* Figure 5: The observed tree cover in the treatment forests and their counterfactual cover ...
* Figure 6: The relationship between the average rate of November fire occurrences in subforests ...
* Figure 7: Estimates of the heterogeneous treatment effects on November forest fire occurrences for the various socio-economic characteristics ...
* Figure C.1: The evolution of fire occurrences in FIP and non-FIP forests over the period 2003-2013.
* Figure C.2: November forest fire occurrences in the FIP forests and the corresponding synthetic controls.
* Figure C.3: Fire occurrences with a detection confidence of 50\% or better in the FIP forests and their synthetic controls
* Figure C.4: Observed fire occurrence in November in the interior of the forest
* Figure C.5: Observed number of fires that were started, their average size, and the estimated counterfactuals in FIP forests in November.

* **************************************************************************** *


* ----------------------------------------------------------------------------
* Figure 1: Average precipitation per month of the year (left axis and grey bars) ...
	use "$RepPack_dtFin/burkina_faso_fires-YEAR_FOREST.dta", clear

		keep forestid year fireBurn? fireBurn1? precipCHIRPS? precipCHIRPS1?
		keep if year<=2013
		collapse (mean) fireBurn? fireBurn1? precipCHIRPS? precipCHIRPS1?, by(year)
		reshape long fireBurn precipCHIRPS, i(year) j(month)
		collapse (mean) fireBurn precipCHIRPS, by(month)
		
		gen monthOrder = mod(month+7, 12)
		lab drop product
		lab def monthOrder  0 "May" 1 "June" 2 "July" 3 "August" 4 "September" 5 "October" ///
							6 "November" 7 "December" 8 "January" 9 "February" 10 "March" ///
							11 "April"
		lab val monthOrder monthOrder
		sort monthOrder
		
		twoway  (bar precipCHIRPS monthOrder, fcolor(blue%20) lcolor(none) lw(none))   ///
			(line fireBurn monthOrder , lc(red) lw(medium) yaxis(2)), 			///
			ytitle("Share of forest area that was affected by " "fire at least once in the month.", axis(2))	///
			ytitle("Avg. monthly precipitation in mm.") 						///
			xtitle("") xlabel(0(2)11, valuelabel alternate) 					///
			legend(label(1 "Precipitation") label(2 "Fire") nobox region(col(white))) ///
			graphregion(color(white)) bgcolor(white)
			
		graph export "$RepPack_OutFigures/fig1_fire_and_rain.png", as(png) width(2000) replace
		graph drop _all
		
		
		
* ----------------------------------------------------------------------------
* Figure 3: Monthly fire occurrences in the FIP and non-FIP forests ...
use "$RepPack_dtInt/burkina_faso_fires-MONTH_FOREST.dta", clear

	keep year month treatment conf30 conf50 conf80
	keep if year<=2013
	collapse (mean) conf30 conf50 conf80 	///
			 (p25)  p25conf30=conf30 p25conf50=conf50 p25conf80=conf80 ///
			 (p75)	p75conf30=conf30 p75conf50=conf50 p75conf80=conf80, by(treatment month)
	gen monthOrder = mod(month+7, 12)
	lab def monthOrder  0 "May" 1 "June" 2 "July" 3 "August" 4 "September" 5 "October" ///
						6 "November" 7 "December" 8 "January" 9 "February" 10 "March" ///
						11 "April"
	lab val monthOrder monthOrder
	sort monthOrder treatment
	
	capture graph drop _all				
	twoway  (rarea p25conf30 p75conf30 monthOrder if treatment==0, color(red%20)) ///
			(rarea p25conf30 p75conf30 monthOrder if treatment==1, color(blue%20)) ///
			(line conf30 monthOrder if treatment==0, lc(red) lp(dash) lw(medthick)) ///
			(line conf30 monthOrder if treatment==1, lc(blue) lp(solid) lw(medthick)), ///
			xtitle("Confidence>=30%") xlabel(0(2)11, valuelabel alternate) xscale(titlegap(*7)) ///
			ytitle("Fire occurrence") title("(a)") ///
			graphregion(color(white)) bgcolor(white) name(gr_conf30) legend(off)
	twoway  (rarea p25conf50 p75conf50 monthOrder if treatment==0, color(red%20)) ///
			(rarea p25conf50 p75conf50 monthOrder if treatment==1, color(blue%20)) ///
			(line conf50 monthOrder if treatment==0, lc(red) lp(dash) lw(medthick)) ///
			(line conf50 monthOrder if treatment==1, lc(blue) lp(solid) lw(medthick)), ///
			xtitle("Confidence>=50%") xlabel(0(2)11, valuelabel alternate) xscale(titlegap(*7)) ///
			ytitle("") title("(b)") ///
			legend(order(3 4) label(3 "Non-project forests") label(4 "Project forests") /// 
			nobox region(col(white))) ///
			graphregion(color(white)) bgcolor(white) name(gr_conf50)
	twoway  (rarea p25conf80 p75conf80 monthOrder if treatment==0, color(red%20)) ///
			(rarea p25conf80 p75conf80 monthOrder if treatment==1, color(blue%20)) ///
			(line conf80 monthOrder if treatment==0, lc(red) lp(dash) lw(medthick)) ///
			(line conf80 monthOrder if treatment==1, lc(blue) lp(solid) lw(medthick)), ///
			xtitle("Confidence>=80%") xlabel(0(2)11, valuelabel alternate) xscale(titlegap(*7)) ///
			ytitle("") title("(c)") ///
			graphregion(color(white)) bgcolor(white) name(gr_conf80) legend(off)
	
	grc1leg gr_conf30 gr_conf50 gr_conf80, rows(1) graphregion(color(white)) ///
					ycommon plotregion(color(white))  ///
					iscale(*0.7) legendfrom(gr_conf50)
	
	graph export "$RepPack_OutFigures/fig3_TS_raw_ALL_FORESTS_conf.png", as(png) width(2000) replace
	graph drop _all
		
		
		
		
* ------------------------------------------------------------------------------		
* Figure 4: Fire occurrence in the FIP forests in each of the seven dry months of the year ...
	local outCVars			"conf301 conf302 conf303 conf304 conf3010 conf3011 conf3012"
	global gl_covVars  		"area precipYear"
	global gl_treat2015Vars "conf301 conf302 conf303 conf304"
	global gl_noNestedVars  "$gl_outCVars"
	global gl_workingfolder "${RepPack_OutRaw}/Synthetic/fire_occurrence"
	global gl_resultestsfile "fire_occurrence_results"
	
	local j = 1
	foreach var of local outCVars{
	    
		capture confirm file "${gl_workingfolder}/`var'/TC_`var'_manual.png"
		if _rc!=0 {
		    global gl_covVars	"`var'"
			use "$RepPack_dtFin/burkina_faso_fires-YEAR_FOREST.dta", clear
				
				keep forestid forest_name year post* treatment $gl_outCVars $gl_covVars
				
				do "${RepPack_doutility}/SCMresults.do"
		}
	
		local char = substr("DEFGABC",`j',1)
		local ++j
		copy 	"${gl_workingfolder}/`var'/TC_`var'_manual.png" ///
				"${RepPack_OutFigures}/fig4s`char'_TC_`var'.png", replace
	}

		
		
* ------------------------------------------------------------------------------
* Figure 5: The observed tree cover in the treatment forests and their counterfactual cover ...
	global gl_outCVars = "treecover"
	global gl_covVars  		"area precipYear"
	global gl_treat2015Vars ""
	global gl_noNestedVars  "treecover"
	global gl_workingfolder "${RepPack_OutRaw}/Synthetic/vegetation_cover"
	global gl_resultestsfile "vegetation_results"
	
	use "$RepPack_dtFin/burkina_faso_fires_tcover-YEAR_FOREST.dta", clear
		
		keep forestid forest_name year post* treatment $gl_outCVars $gl_covVars
		
		do "${RepPack_doutility}/SCMresults.do"
		
		copy 	"${gl_workingfolder}/treecover/TC_treecover_manual.png" ///
				"${RepPack_OutFigures}/fig5_TC_treecover.png", replace
				

				
				
* ------------------------------------------------------------------------------				
* Figure 6: The relationship between the average rate of November fire occurrences in subforests ...
use "$RepPack_dtFin/burkina_faso_fires_forestblock-YEAR.dta", clear

	global gl_covariates = "n_HH HH_educ_prim lavg_dur_value A5BIS " ///
						+ "inorg_fert org_fert distSettlRoad distToRoad minDistanceSettl"
						
						
	su gridid if year==2010 & treatment==1, detail
	local gridThreshold	= `r(p10)'
	keep if gridid >= `gridThreshold'
	keep if year>=2003 & year < 2013
	keep forestBlockID forestid treatment conf3011 conf5011 year $gl_covariates B8_animiste
	
	collapse (mean) conf3011 conf5011 (first) $gl_covariates B8_animiste treatment forestid, by(forestBlockID)
	

	lab var n_HH			"Number of households"
	lab var A5BIS			"% farmer households"
	lab var org_fert		"% households using organic fertilizers"
	lab var inorg_fert		"% households using inorganic fertilizers"
	lab var HH_educ_prim	"% households heads with primary education or better"
	lab var lavg_dur_value	"ln(Value of household assets)"
	lab var distSettlRoad	"Distance to the main road"
	lab var minDistanceSettl "Distance to the village's subforest"
	lab var distToRoad		"Distance from subforest to the main road "
	
	foreach var of global gl_covariates {		// Normalize variables	
		qui egen m`var' = mean(`var')
		qui egen s`var' = sd(`var')
		qui replace `var' = (`var' - m`var') / s`var'
	}
	
	estimates clear
	eststo conf3011treat: reg conf3011 $gl_covariates B8_animiste if treatment==1, vce(cluster forestid)
		local NBlocksTreat = e(N)
	

	coefplot conf3011treat, keep($gl_covariates) drop(_cons) xline(0) mlabpos(5)	///
			mlabel( cond(@pval<=.1, cond(@pval<=.05, cond(@pval<=.01, string(@b,"%4.3f")+"***", string(@b,"%4.3f")+"**"), string(@b,"%4.3f")+"*"), "") ) ///
			coeflabels(, labsize(small)) levels(90) ///
			note("Regression includes all partitions (N=`NBlocksTreat')") ///
			xtitle("Number of days the forest's average a grid cell is on fire", size(small) justification(right)) ///
			graphregion(color(white)) bgcolor(white) replace
	graph export  "${RepPack_OutFigures}/fig6_Descriptive_regression_FIPFOR.eps", as(eps) replace
	graph drop _all


	
	
* ------------------------------------------------------------------------------				
* Figure 7: Estimates of the heterogeneous treatment effects on November forest fire occurrences for the various socio-economic characteristics ...
// Estimate subforest level effects
use "$RepPack_dtFin/burkina_faso_fires_forestblock-YEAR.dta", clear

	
	su gridid if year==2010 & treatment==1, detail
	drop if inlist(year, 2003) | (gridid < r(p10))

	global gl_covariates = "n_HH HH_educ_prim lavg_dur_value A5BIS " 			///
						 + "inorg_fert org_fert distSettlRoad distToRoad minDistanceSettl"
						 
	foreach var of global gl_covariates {		// Normalize variables
		qui egen m`var' = mean(`var')
		qui egen s`var' = sd(`var')
		qui replace `var' = (`var' - m`var') / s`var'
	}

	global gl_outCVars 		"conf3011"
	global gl_covVars  		"area precipYear $gl_covariates"
	global gl_treat2015Vars "conf301 conf302 conf303 conf304"
	global gl_noNestedVars  "$gl_outCVars"
	global gl_workingfolder "${RepPack_OutRaw}/Synthetic/fire_occurrence_partitions"
	global gl_resultestsfile "fire_occurrence_partitions_results"
	
		keep forestBlockID forest_name year post* treatment $gl_outCVars $gl_covVars 
		drop if inlist(forestBlockID, 76117, 77375, 50117)		// missing values
		
		do "${RepPack_doutility}/SCMresults_partitions.do"

// Combine estimated results and estimate random-effects model
use	 "$RepPack_dtFin/burkina_faso_fires_forestblock-YEAR.dta", clear

	global gl_covariates = "n_HH HH_educ_prim lavg_dur_value A5BIS " ///
						 + "inorg_fert org_fert distSettlRoad distToRoad minDistanceSettl"

	su gridid if year==2010 & treatment==1, detail
	local gridThreshold	= `r(p10)'
	keep if gridid >= `gridThreshold' 
	
	keep if inrange(year, 2004, 2019) & treatment==1
	keep forestBlockID forestid year treatment conf3011 $gl_covariates REGION
	
	
	foreach var of global gl_covariates {		// Normalize variables
		qui egen m`var' = mean(`var')
		qui egen s`var' = sd(`var')
		qui replace `var' = (`var' - m`var') / s`var'
	}

	** Merge in estimated effects and calculate pre-treatment average fire occurrence
	merge 1:1 forestBlockID year using "${RepPack_OutRaw}/Synthetic/fire_occurrence_partitions/conf3011/SC_conf3011.dta", ///
			keepusing(effect) gen(_mergepart)
	
	bysort forestBlockID (year): egen avg_conf3011_mean = mean(conf3011) if year<2014
	bysort forestBlockID (year): egen avg_conf3011 = mean(avg_conf3011_mean)
			
	lab var n_HH			"Number of households"
	lab var A5BIS			"% farmer households"
	lab var org_fert		"% households using organic fertilizers"
	lab var inorg_fert		"% households using inorganic fertilizers"
	lab var HH_educ_prim	"% households heads with primary education or better"
	lab var lavg_dur_value	"ln(Value of household assets)"
	lab var distSettlRoad	"Distance to the main road"
	lab var minDistanceSettl "Distance to the village's subforest"
	lab var distToRoad		"Distance from subforest to the main road "
	lab var avg_conf3011	"Avg. pre-treatm. fire occ."
	
	** Panel RE regression
	estimates clear
	xtreg effect $gl_covariates avg_conf3011 i.year i.REGION if year>=2014, re vce(robust)
	estimates store y2014
	
	** Plot coefficients
	coefplot (y2014, keep(avg_conf3011 $gl_covariates )),		///
				order(avg_conf3011 $gl_covariates )				///
				mlabpos(5) xline(0)	levels(90)					///
				mlabel( cond(@pval<=.1, cond(@pval<=.05,cond(@pval<=.01,string(@b,"%4.3f")+"***",string(@b,"%4.3f")+"**"),string(@b,"%4.3f")+"*"), "")) ///
				legend(off) graphregion(color(white)) bgcolor(white)
	
	graph export    "${RepPack_OutFigures}/fig7_Heterogenous_effects_conf3011.eps", as(eps) replace
	graph drop _all
	
	
	

* ------------------------------------------------------------------------------				
* Figure C.1: The evolution of fire occurrences in FIP and non-FIP forests over the period 2003-2013.
use "$RepPack_dtFin/burkina_faso_fires-YEAR_FOREST.dta", clear
		
		keep year treatment conf?011 conf?012
		keep if year<=2013
		collapse (mean) conf3011 conf3012 conf5011 conf5012		///
				 (p25) 	p25conf3011=conf3011 p25conf3012=conf3012 p25conf5011=conf5011 p25conf5012=conf5012	///
				 (p75) 	p75conf3011=conf3011 p75conf3012=conf3012 p75conf5011=conf5011 p75conf5012=conf5012	, by(treatment year)
				 
		gen yeartreat = year*10 + treatment
		drop if treatment==.
		
		reshape long conf30 conf50 p25conf30 p75conf30 p25conf50 p75conf50, i(yeartreat) j(month)	
		
		lab def month 11 "November" 12 "December"
		lab val month month
				 
		capture graph drop _all
		twoway (line conf30 year if treatment==0, by(month, note("") graphregion(color(white)) ///
					bgcolor(white)) lc(red) lp(dash) lw(medthick)) 				///
				(line conf30 year if treatment==1, lc(blue) lp(solid) lw(medthick))	///
				(rarea p25conf30 p75conf30 year if treatment==0, color(red%15))  ///
				(rarea p25conf30 p75conf30 year if treatment==1, color(blue%15)),  ///
				xlabel(2003(2)2013, labsize(small)) xtitle("Year") 				///
				ylabel(0(0.2)1) ytitle("Fire occurrence") 						///
				legend(order(1 2) label(1 "Non-project forests") label(2 "Project forests") nobox region(col(white)))
		
		graph export "$RepPack_OutFigures/Appendix/figc1_TS_raw_ALL_FORESTS_conftime.png", as(png) width(2000) replace
		
		
* ------------------------------------------------------------------------------				
* Figure C.2: November forest fire occurrences in the FIP forests and the corresponding synthetic controls.
	global gl_covVars  		"area precipYear"
	global gl_treat2015Vars ""
	global gl_noNestedVars  "conf3011"
	global gl_workingfolder "${RepPack_OutRaw}/Synthetic/fire_occurrence"
	global gl_resultestsfile "fire_occurrence_results"
	
	capture confirm file "${gl_workingfolder}/conf3011/TC_conf3011_forests.eps"
	
	if _rc!=0 {
		global gl_outCVars 		"conf3011"
		
		use "$RepPack_dtFin/burkina_faso_fires-YEAR_FOREST.dta", clear
			
			keep forestid forest_name year post* treatment $gl_outCVars $gl_covVars
			
			do "${RepPack_doutility}/SCMresults.do"
	}
		
	copy 	"${gl_workingfolder}/conf3011/TC_conf3011_forests.eps" ///
			"${RepPack_OutFigures}/Appendix/figc2_TC_conf3011_forests.eps", replace	
				
				

* ------------------------------------------------------------------------------
* Figure C.3: Fire occurrences with a detection confidence of 50\% or better in the FIP forests and their synthetic controls
	local outCVars			"conf501 conf502 conf503 conf504 conf5010 conf5011 conf5012"
	global gl_covVars  		"area precipYear"
	global gl_treat2015Vars "conf501 conf502 conf503 conf504"
	global gl_noNestedVars  "$gl_outCVars"
	global gl_workingfolder "${RepPack_OutRaw}/Synthetic/fire_occurrence"
	global gl_resultestsfile "fire_occurrence_results"
	
	local j = 1
	foreach var of local outCVars{
	    
		capture confirm file "${gl_workingfolder}/`var'/TC_`var'_manual.png"
		if _rc!=0 {
		    global gl_covVars	"`var'"
			use "$RepPack_dtFin/burkina_faso_fires-YEAR_FOREST.dta", clear
				
				keep forestid forest_name year post* treatment $gl_outCVars $gl_covVars
				
				do "${RepPack_doutility}/SCMresults.do"
		}
	
		local char = substr("DEFGABC",`j',1)
		local ++j
		copy 	"${gl_workingfolder}/`var'/TC_`var'_manual.png" ///
				"${RepPack_OutFigures}/Appendix/figc3s`char'_TC_`var'.png", replace
	}
		
		

* ------------------------------------------------------------------------------
* Figure C.4: Observed fire occurrence in November in the interior of the forest
	global gl_covVars  		"area precipYear"
	global gl_treat2015Vars ""
	global gl_noNestedVars  ""
	global gl_workingfolder "${RepPack_OutRaw}/Synthetic/fire_occurrence"
	global gl_resultestsfile "fire_occurrence_results"
	
	// 1 km threshold
	global gl_outCVars = "conf30_aE100011"
	capture confirm file "${gl_workingfolder}/conf30_aE100011/TC_conf30_aE100011_manual.png"
	
	if _rc!=0 {
		use "$RepPack_dtFin/burkina_faso_fires-YEAR_FOREST.dta", clear
			keep forestid forest_name year post* treatment $gl_outCVars $gl_covVars
			bysort forestid (year): egen conf30_aE100011_miss = count(conf30_aE100011)
			bysort forestid (year): replace conf30_aE100011_miss = conf30_aE100011_miss < _N
			drop if conf30_aE100011_miss == 1
			drop conf30_aE100011_miss
			
			do "${RepPack_doutility}/SCMresults.do"
	}
	copy 	"${gl_workingfolder}/conf30_aE100011/TC_conf30_aE100011_manual.png" ///
			"${RepPack_OutFigures}/Appendix/figc4sA_TC_conf30_aE100011.png", replace
	
	
	// 2 km threshold
	global gl_outCVars = "conf30_aE200011"
	global gl_noNestedVars  "$gl_outCVars"
	capture confirm file "${gl_workingfolder}/conf30_aE200011/TC_conf30_aE200011_manual.png"
	
	if _rc!=0 {
		use "$RepPack_dtFin/burkina_faso_fires-YEAR_FOREST.dta", clear
			keep forestid forest_name year post* treatment $gl_outCVars $gl_covVars
	
			bysort forestid (year): egen conf30_aE200011_miss = count(conf30_aE200011)
			bysort forestid (year): replace conf30_aE200011_miss = conf30_aE200011_miss < _N
			drop if conf30_aE200011_miss == 1
			drop conf30_aE200011_miss
	
		do "${RepPack_doutility}/SCMresults.do"
	}
	copy 	"${gl_workingfolder}/conf30_aE200011/TC_conf30_aE200011_manual.png" ///
			"${RepPack_OutFigures}/Appendix/figc4sB_TC_conf30_aE200011.png", replace
		
		
* ------------------------------------------------------------------------------
* Figure C.5: Observed number of fires that were started, their average size, and the estimated counterfactuals in FIP forests in November.
	local varlist 		"conf30Burn11 conf30Sett11 conf30Area11" 
	global gl_covVars  		"area precipYear"
	global gl_treat2015Vars ""
	global gl_noNestedVars  "`varlist'"
	global gl_workingfolder "${RepPack_OutRaw}/Synthetic/fire_occurrence"
	global gl_resultestsfile "fire_occurrence_results"
	
	local j = 1 
	foreach var of local varlist {
		global gl_outCVars	"`var'"
		
		capture confirm file  "${gl_workingfolder}/`var'/TC_`var'_manual.png"
		if _rc!=0 {
			use "$RepPack_dtFin/burkina_faso_fires-YEAR_FOREST.dta", clear
				keep forestid forest_name year post* treatment $gl_outCVars $gl_covVars
				drop if inlist(year, 2003, 20020)
				
				do "${RepPack_doutility}/SCMresults.do"
		}
			
		local char = substr("ABC",`j',1)
		local ++j
		copy 	"${gl_workingfolder}/`var'/TC_`var'_manual.png" ///
				"${RepPack_OutFigures}/Appendix/figc5s`char'_TC_`var'.png", replace
	}
		
		
