* **************************************************************************** *
* **************************************************************************** *
*           Combatting forest fires in the drylands of Sub-Saharan Africa:     *
*                Quas-experimental evidence from Burkina Faso                  *
* **************************************************************************** *
* **************************************************************************** *
/*
** PURPOSE:     Generation of Tables
** IDS VAR:	    forerstid, forestBlockID, year
** WRITTEN BY:	Tung Nguyen Huy (nghuytungi@windowslive.com)
*/
* **************************************************************************** *
* **************************************************************************** *

* Overview of all tables produced in this do file:

* Table 1: Estimated impacts of the forest fire prevention program on forest fire occurrences per calendar month ...
* Table 2: Estimated average treatment effect on number of fire occurrences excluding the forest fringe
* Table 3: Impact of the intervention on the share of forests affected by fire in November in each of the post-intervention years ...
* Table 4: Characteristics of the villages surrounding FIP and non-FIP subforests.
* Table C.1: Weights of on-treated forests in the synthetic control unit of treated forests...
* Table C.2: Estimated impacts of the program on forest fire occurrences for the set of non-contiguous treatment and control forests

* **************************************************************************** *


* ----------------------------------------------------------------------------
* Table 1: Estimated impacts of the forest fire prevention program on forest fire occurrences per calendar month ...
global gl_outCVars 	= "conf301 conf302 conf303 conf304 conf3010 conf3011 conf3012 " ///
					+"conf501 conf502 conf503 conf504 conf5010 conf5011 conf5012 " 
global gl_covVars  		"area precipYear"
global gl_treat2015Vars "conf301 conf302 conf303 conf304 conf501 conf502 conf503 conf504"
global gl_noNestedVars  "conf3010 conf5010 conf3011 conf5011"
global gl_workingfolder "$RepPack_OutRaw/Synthetic/fire_occurrence"
global gl_resultestsfile "fire_occurrence_results"


// Estimate results
use "$RepPack_dtFin/burkina_faso_fires-YEAR_FOREST.dta", clear
	
	keep forestid forest_name year post* treatment $gl_outCVars $gl_covVars
 	
	do "$RepPack_doutility/SCMresults.do"


// Export SCM results to tables
use "${RepPack_OutRaw}/Synthetic/fire_occurrence/fire_occurrence_results.dta", clear
	
		// Select relevant columns and rows
		capture drop conf80*
		sort year
		gen rowid = _n
		reshape long conf30 conf50, i(rowid) j(month) 
		recode month (10=1) (11=2) (12=3) (1=4) (2=5) (3=6) (4=7), gen(monthorder)
		gsort monthorder year rowtype
		
		drop if (conf30=="" & conf50=="") | (inlist(rowid, 13, 14))
		bysort month (year rowtype): replace month = . if _n!=1
		gsort monthorder year rowtype
		replace year=. 	if rowtype==1 					
		keep month year conf30 conf50 monthorder
		
		// Labels
		gen 	monthstr = "Oct"		if month==10
		replace monthstr = "Nov"		if month==11
		replace monthstr = "Dec"		if month==12
		replace monthstr = "Jan"		if month==1
		replace monthstr = "Feb"		if month==2
		replace monthstr = "Mar"		if month==3
		replace monthstr = "Apr"		if month==4
		rename (monthstr year conf30 conf50) (Month Year C30 C50)
	
	
	// Outsheet
	texsave Month Year C30 C50	using "${RepPack_OutRaw}/Synthetic/fire_occurrence/temp_p1_1.tex" ///
		if monthorder<=3, 																///
		headerlines("& & (1) & (2)" " & & \multicolumn{2}{c}{Fire occurrences}")		///
		size(footnotesize) width(0.925\linewidth) hlines(12 24) frag nofix replace
		
		filefilter "${RepPack_OutRaw}/Synthetic/fire_occurrence/temp_p1_1.tex" ///
					"${RepPack_OutRaw}/Synthetic/fire_occurrence/temp_p1_2.tex", ///
					from("\BSbegin{table}[tbp] \BScentering") ///
					to("") replace
		filefilter "${RepPack_OutRaw}/Synthetic/fire_occurrence/temp_p1_2.tex" ///
					"${RepPack_OutRaw}/Synthetic/fire_occurrence/temp_p1_3.tex", ///
					from("&--") ///
					to("&-") replace
		filefilter "${RepPack_OutRaw}/Synthetic/fire_occurrence/temp_p1_3.tex" ///
					"$RepPack_OutTables/tab1_fire_occurrence_results_p1.tex", ///
					from("\BSend{table}") to("") replace
	
	texsave Month Year C30 C50 using "${RepPack_OutRaw}/Synthetic/fire_occurrence/temp_p2_1.tex" ///
		if monthorder>3, 																///
		headerlines("& & (1) & (2)" " & & \multicolumn{2}{c}{Fire occurrences}") 		///
		size(footnotesize) width(0.925\linewidth) hlines(10 20 30) frag nofix replace
		
		filefilter "${RepPack_OutRaw}/Synthetic/fire_occurrence/temp_p2_1.tex" ///
					"${RepPack_OutRaw}/Synthetic/fire_occurrence/temp_p2_2.tex", ///
					from("\BSbegin{table}[tbp] \BScentering") ///
					to("") replace
		filefilter "${RepPack_OutRaw}/Synthetic/fire_occurrence/temp_p2_2.tex" ///
					"${RepPack_OutRaw}/Synthetic/fire_occurrence/temp_p2_3.tex", ///
					from("&--") ///
					to("&-") replace
		filefilter "${RepPack_OutRaw}/Synthetic/fire_occurrence/temp_p2_3.tex" ///
					"$RepPack_OutTables/tab1_fire_occurrence_results_p2.tex", ///
					from("\BSend{table}") to("") replace

	erase "${RepPack_OutRaw}/Synthetic/fire_occurrence/temp_p1_1.tex"
	erase "${RepPack_OutRaw}/Synthetic/fire_occurrence/temp_p1_2.tex"
	erase "${RepPack_OutRaw}/Synthetic/fire_occurrence/temp_p1_3.tex"
	erase "${RepPack_OutRaw}/Synthetic/fire_occurrence/temp_p2_1.tex"
	erase "${RepPack_OutRaw}/Synthetic/fire_occurrence/temp_p2_2.tex"
	erase "${RepPack_OutRaw}/Synthetic/fire_occurrence/temp_p2_3.tex"

	
	

* ----------------------------------------------------------------------------	
* Table 2: Estimated average treatment effect on number of fire occurrences excluding the forest fringe
// Estimate results for fires -- excluding grids within 1 km from forest edge
use "$RepPack_dtFin/burkina_faso_fires-YEAR_FOREST.dta", clear

	
	global gl_outCVars 		"conf30_aE100011"
	global gl_covVars  		"area precipYear"
	global gl_treat2015Vars ""
	global gl_noNestedVars  ""
	global gl_workingfolder "$RepPack_OutRaw/Synthetic/fire_occurrence"
	global gl_resultestsfile "fire_occurrence_results"

	// Drop small forests from donor list with missing values
	keep forestid year treatment post*Treatment $gl_covVars $gl_outCVars conf30_aE100011 
	bysort forestid (year): egen conf30_aE100011_miss = count(conf30_aE100011)
	bysort forestid (year): replace conf30_aE100011_miss = conf30_aE100011_miss < _N
	drop if conf30_aE100011_miss == 1
	drop conf30_aE100011_miss
	
	do "$RepPack_doutility/SCMresults.do"

// Estimate results for fires -- excluding grids within 2 km-s from forest edge		
use "$RepPack_dtFin/burkina_faso_fires-YEAR_FOREST.dta", clear
	
	global gl_outCVars 		"conf30_aE200011"
	global gl_covVars  		"area precipYear"
	global gl_treat2015Vars ""
	global gl_noNestedVars  "$gl_outCVars"
	global gl_workingfolder "$RepPack_OutRaw/Synthetic/fire_occurrence"
	global gl_resultestsfile "fire_occurrence_results"
	
	// Drop small forests from donor list with missing values
	keep forestid year treatment post*Treatment $gl_covVars $gl_outCVars
	bysort forestid (year): egen conf30_aE200011_miss = count(conf30_aE200011)
	bysort forestid (year): replace conf30_aE200011_miss = conf30_aE200011_miss < _N
	drop if conf30_aE200011_miss == 1
	drop conf30_aE200011_miss
	
	do "$RepPack_doutility/SCMresults.do"
	
	
// Export SCM results to tables
use "$RepPack_OutRaw/Synthetic/fire_occurrence/fire_occurrence_results.dta", clear
	sort year rowtype
	su year
	gen Month  = "\multirow{`=r(N)'}{*}{Nov.}" in 1
	keep Month year rowtype conf3011 conf30_aE100011 conf30_aE200011
	order Month year rowtype conf3011 conf30_aE100011 conf30_aE200011
	replace year = . if rowtype==1
	
	lab var Month			"Month"
	lab var year			"Year"
	lab var conf3011		"No thresh."
	lab var conf30_aE100011 "1 km thresh."
	lab var conf30_aE200011 "2 km thresh."
		
	// Outsheet
	texsave Month year conf3011 conf30_aE100011 conf30_aE200011 ///
		using "$RepPack_OutRaw/Synthetic/fire_occurrence/temp_p1_1.tex", 		 		///
		headerlines(" & & (1) & (2) & (3)" "& & \multicolumn{3}{c}{Fire occurrences}")  ///
		varlabels size(footnotesize) width(0.925\linewidth) frag nofix replace
		
	filefilter "$RepPack_OutRaw/Synthetic/fire_occurrence/temp_p1_1.tex" 	///
				"$RepPack_OutRaw/Synthetic/fire_occurrence/temp_p1_2.tex", 	///
				from("\BSbegin{table}[tbp] \BScentering") 					///
				to("") replace
	filefilter "$RepPack_OutRaw/Synthetic/fire_occurrence/temp_p1_2.tex" 			///
				"$RepPack_OutTables/tab2_fire_occ_borderlineation.tex", 	///
				from("\BSend{table}") to("") replace
				
	erase "$RepPack_OutRaw/Synthetic/fire_occurrence/temp_p1_1.tex"
	erase "$RepPack_OutRaw/Synthetic/fire_occurrence/temp_p1_2.tex"
	
	
	
	
* ----------------------------------------------------------------------------	
* Table 3: Impact of the intervention on the share of forests affected by fire in November in each of the post-intervention years ...
use "$RepPack_dtFin/burkina_faso_fires-YEAR_FOREST.dta", clear

	drop if inlist(year, 2003)
	global gl_outCVars 	"conf30Sett11 conf30Area11 conf30Burn11"
	global gl_covVars  		"area precipYear"
	global gl_treat2015Vars ""
	global gl_noNestedVars  "$gl_outCVars"
	global gl_workingfolder "$RepPack_OutRaw/Synthetic/fire_occurrence"
	global gl_resultestsfile "fire_occurrence_results"

	keep forestid year treatment post*Treatment $gl_covVars $gl_outCVars
	
	do "$RepPack_doutility/SCMresults.do"
	
	
// Export SCM results to tables
use "$RepPack_OutRaw/Synthetic/fire_occurrence/fire_occurrence_results.dta", clear
	sort year rowtype
	su year
	gen Month  = "\multirow{`=r(N)'}{*}{Nov.}" in 1
	replace year = . if rowtype==1
	keep Month year rowtype conf3011 conf30Sett11 conf30Area11 conf30Burn11
	order Month year conf3011 conf30Burn11 conf30Area11 conf30Sett11
	
	
	lab var Month 		"Month"
	lab var year		"Year"
	lab var conf3011 	"Fire occurrence"
	lab var conf30Burn11 "\makecell{Share of fire \\ affected grids \\ in November}"
	lab var conf30Sett11 "\# of ignitions"
	lab var conf30Area11 "Avg. fire spread"
	
	// Outsheet
	texsave Month year conf30Burn11 conf30Sett11 conf30Area11 				///
		using "$RepPack_OutRaw/Synthetic/fire_occurrence/temp_p1_1.tex", 	///
		headerlines(" & & (1) & (2) & (3) ") varlabels 						///
		size(footnotesize) width(0.925\linewidth) frag nofix replace
	
		filefilter "$RepPack_OutRaw/Synthetic/fire_occurrence/temp_p1_1.tex" 	///
					"$RepPack_OutRaw/Synthetic/fire_occurrence/temp_p1_2.tex", 	///
					from("\BSbegin{table}[tbp] \BScentering") to("") replace
		filefilter "$RepPack_OutRaw/Synthetic/fire_occurrence/temp_p1_2.tex" 	///
					"$RepPack_OutTables/tab3_fire_occ_ign_size.tex", 				///
					from("\BSend{table}") to("") replace
	
	erase "$RepPack_OutRaw/Synthetic/fire_occurrence/temp_p1_1.tex"
	erase "$RepPack_OutRaw/Synthetic/fire_occurrence/temp_p1_2.tex"



	
* ----------------------------------------------------------------------------
* Table 4: Characteristics of the villages surrounding FIP and non-FIP subforests.
use "$RepPack_dtFin/burkina_faso_fires_forestblock-YEAR.dta", clear

	keep if year==2010
	su gridid				if year==2010 & treatment==1, detail
	local gridThreshold		= `r(p10)'
	keep					if gridid >= `gridThreshold'
	keep forestBlockID forestid treatment n_HH HH_educ_prim lavg_dur_value A5BIS 	///
		org_fert inorg_fert distSettlRoad distToRoad minDistanceSettl avg_dur_value
		
		
	replace distSettlRoad = distSettlRoad / 1000
	replace distToRoad = distToRoad / 1000
	replace minDistanceSettl = minDistanceSettl / 10000
		
	lab var n_HH			"Number of households"
	lab var A5BIS			"Share of farmer households"
	lab var org_fert		"Share of households using organic fertilizers"
	lab var inorg_fert		"Share of households using inorganic fertilizers"
	lab var HH_educ_prim	"Share of households heads with primary education or better"
	lab var lavg_dur_value	"Value of household assets (FCFA, in natural logarithms)"
	lab var distSettlRoad	"Distance to the main road (in km) "
	lab var minDistanceSettl "Distance to the village's subforest (in km)"
	lab var distToRoad		"Distance from village's subforest to the main road (in km)"
	
	iebaltabmod n_HH A5BIS org_fert inorg_fert	///
				HH_educ_prim lavg_dur_value distSettlRoad minDistanceSettl distToRoad,		///
				grpvar(treatment) order(1 0) 										///
				grplabels(1 "\makecell{Villages surrounding \\ FIP forests}" 		///
						@ 0 "\makecell{Villages surrounding \\ non-FIP forests}") 	///
				total totalfirst rowvarlabels stdev tblnonote onerow nottest replace ///
				savetex("$RepPack_OutTables/temp.tex")
				
				
	filefilter "$RepPack_OutTables/temp.tex" "$RepPack_OutTables/temp2.tex", ///
				from("(n_HH)") to("(1)") replace
	filefilter "$RepPack_OutTables/temp2.tex" "$RepPack_OutTables/temp.tex", ///
				from("Total") to("\BSmakecell{Overall village \BS\BS characteristics}") replace
	filefilter "$RepPack_OutTables/temp.tex" "$RepPack_OutTables/tab4_LSMS_descriptives.tex", ///
				from("Mean/SD") to("Mean (SD)") replace			
	
	erase "$RepPack_OutTables/temp.tex"
	erase "$RepPack_OutTables/temp2.tex"

	
	
	
* ------------------------------------------------------------------------------
* Table C.1: Weights of non-treated forests in the synthetic control unit of treated forests for November fire occurrences
capture confirm file "$RepPack_OutRaw/Synthetic/fire_occurrence/conf3011/W_file.dta"
if _rc!=0 {
	use "$RepPack_dtFin/burkina_faso_fires-YEAR_FOREST.dta", clear

		global gl_outCVars 		"conf3011"
		global gl_covVars  		"area precipYear"
		global gl_treat2015Vars ""
		global gl_noNestedVars  "conf3011"
		global gl_workingfolder "$RepPack_OutRaw/Synthetic/fire_occurrence"
		global gl_resultestsfile "fire_occurrence_results"
		
		keep forestid year post* treatment $gl_covVars $gl_outCVars
		drop if inlist(year, 2003)
		
		do "$RepPack_doutility/SCMresults.do"
}

	// Export weights to a latex table
	use "$RepPack_OutRaw/Synthetic/fire_occurrence/conf3011/W_file.dta", clear
	
		drop tr_year
		drop if inrange(tr_forestid,13,77)
		
		reshape wide _W_Weight, i(_Co_Number) j(tr_forestid)
		
		egen _W_WeightMax = rowmax(_W_Weight? _W_Weight1?)
		drop if _W_WeightMax == 0
		drop _W_WeightMax
		
		su _Co_Number
		local N = _N
		set obs `=`N'+1'
		replace _Co_Number = 999 if _Co_Number==.
		forvalues fid=1/12 {
			gen weight`fid'_dummy = _W_Weight`fid' > 0		if _Co_Number!=999
			egen NumDonors`fid' = total(weight`fid'_dummy)	
			replace _W_Weight`fid'= NumDonors`fid'			if _Co_Number==999
			
			lab var _W_Weight`fid' 	"`fid'"
		}
		
		label var _Co_Number 	"\makecell{Donor forests \\ (ID)}"
		
		texsave	_Co_Number _W_Weight? _W_Weight1? 					///
			using "$RepPack_OutTables/temp1.tex",	///
			headerlines("& \multicolumn{12}{c}{ID of FIP forests}") ///
			size(footnotesize) width(0.9\linewidth) hlines(34) nofix varlabels frag replace
			
		filefilter "$RepPack_OutTables/temp1.tex" "$RepPack_OutTables/temp2.tex", ///
				from("999") to("\BS# donors") replace
		
		filefilter "$RepPack_OutTables/temp2.tex" "$RepPack_OutTables/temp1.tex", ///
				from("\BSbegin{table}[tbp] \BScentering") to("") replace
				
		filefilter "$RepPack_OutTables/temp1.tex" ///
				"$RepPack_OutTables/Appendix/tabc1_fire_occurrence_conf3011_weights.tex", ///
				from("\BSend{table}") to("") replace
				
			
		erase "$RepPack_OutTables/temp1.tex"
		erase "$RepPack_OutTables/temp2.tex"
	

	
* ----------------------------------------------------------------------------
* Table C.2: Estimated impacts of the program on forest fire occurrences for the set of non-contiguous treatment and control forests
// Estimate results
use "$RepPack_dtFin/burkina_faso_fires-YEAR_FOREST.dta", clear
	global gl_outCVars  	" conf3011 conf5011 " 
	global gl_covVars  		"area precipYear"
	global gl_treat2015Vars ""
	global gl_noNestedVars  "conf3011 "
	global gl_workingfolder "$RepPack_OutRaw/Synthetic/fire_occurrence_robust"
	global gl_resultestsfile "fire_occurrence_results_robust"

	keep forestid forest_name year post* treatment $gl_outCVars $gl_covVars neighb_T
	drop if neighb_T==1
	
 	do "$RepPack_doutility/SCMresults.do"
	
// Export SCM results to tables
use "$RepPack_OutRaw/Synthetic/fire_occurrence_robust/fire_occurrence_results_robust.dta", clear
	
	// Prepare results to export
	gen Month = "\multirow{`=r(N)'}{*}{Nov.}" in 1
	replace year = . if rowtype==1
	order Month year conf3011 conf5011
	
	lab var Month	"Month"
	lab var year	"Year"
	lab var conf3011 "Confidence>=30\%"
	lab var conf5011 "Confidence>=50\%"
	
	// Outsheet
	texsave Month year conf3011	conf5011 ///
		using "$RepPack_OutRaw/Synthetic/fire_occurrence_robust/temp_p1_1.tex", ///
		headerlines(" & &  (1) & (2)" " & & \multicolumn{2}{c}{Fire occurrences}") varlabels ///
		size(footnotesize) width(0.85\linewidth) frag nofix replace
	
		filefilter 	"$RepPack_OutRaw/Synthetic/fire_occurrence_robust/temp_p1_1.tex" ///
					"$RepPack_OutRaw/Synthetic/fire_occurrence_robust/temp_p1_2.tex", ///
					from("\BSbegin{table}[tbp] \BScentering") ///
					to("") replace
		filefilter "$RepPack_OutRaw/Synthetic/fire_occurrence_robust/temp_p1_2.tex" ///
					"$RepPack_OutTables/Appendix/tabc2_fire_occurrence_results_spilloverrobust.tex", ///
					from("\BSend{table}") to("") replace
					
	erase "$RepPack_OutRaw/Synthetic/fire_occurrence_robust/temp_p1_1.tex"
	erase "$RepPack_OutRaw/Synthetic/fire_occurrence_robust/temp_p1_2.tex"