
* ------------------------------------------------------------------------------
*  Based on pre-set locals these code snippets generate the SCM estimates.
* ------------------------------------------------------------------------------
//do "$RepPack_doutility/sctabout.do"

local outCVars = "$gl_outCVars"
local covVars = "$gl_covVars"
local treat2015Vars = "$gl_treat2015Vars"
local noNestedVars = "$gl_noNestedVars conf3011 conf5011"
local workingfolder = "$gl_workingfolder"
local resultestsfile = "$gl_resultestsfile"

local forest_name_1 = "Ouro"        					
local forest_name_2 = "Tiogo"       					
local forest_name_3 = "Tisse"       					
local forest_name_4 = "Nossebou"    					
local forest_name_5 = "Sorobouli"   					
local forest_name_6 = "Toroba"      					
local forest_name_7 = "Kari"        					
local forest_name_8 = "Koulbi"      					
local forest_name_9 = "Bontioli (Reserve Totale)"	
local forest_name_10 = "Bontioli (Reserve Partielle)"	
local forest_name_11 = "Nazinon"      					
local forest_name_12 = "Tapoa-Boopo"     


** Estimate SCM for all outcome variable and generate the graphs
foreach var of local outCVars {
	** Determine parameters of SCM
	local startYear = 2013 + (strpos("`treat2015Vars'", "`var'")>0)
	local treatVar	"post`=`startYear'+1'Treatment"
	
	if `startYear'==2013{
		local y2014	""			// Do not fit on 2014 outcome (as pre-treatment period)
	}
	else {
		local y2014 "`var'(2014)" // Fit on 2014 outcome as well
	}
	if "`var'"=="conf3011" {
		local weights 	"aggfile_v(V_file) aggfile_w(W_file)"
		local parallels ""
	}
	else {
		local weights	""
		local parallels "parallel deterministicoutput"
	}
	
	** Determine if nested optimization over W and V should be used
	if strpos("`noNestedVars'","`var'")> 0 	local nested = ""		// simplified procedure
	if strpos("`noNestedVars'","`var'")==0 local nested = "nested"	// full nested optimization - nested

	
	
	if inlist("`var'", "conf303", "conf304", "conf503", "conf504", "conf5010", ///
			 "conf30_aE100011","conf30_aE180011","conf50_aE100011","conf50_aE180011") {
			set seed 123
			replace `var' = rnormal(0.00005, 0.000001) if `var'==0
		}
	
	** Drop treated forests outside the convex hull of donors
	preserve
	if ("`var'"=="conf3012") drop if inlist(forestid, 8, 4)
	if ("`var'"=="conf5012") drop if inlist(forestid, 8, 4)
	if ("`var'"=="conf304") drop if inlist(forestid, 6)
	if ("`var'"=="conf504") drop if inlist(forestid, 6)
	
	** Prepare folders and files
	capture log close
	capture shell rmdir "`workingfolder'/`var'" /s /q
	capture shell mkdir "`workingfolder'/`var'", public
	cd 					"`workingfolder'/`var'"
	log using 			"`workingfolder'/`var'/synth_res_`var'.txt", t replace
	
	** Main stimation and use sctabout to save results
	capture parallel initialize 8 , f 			// Parallel computing to shorten time especially with nested estimation
	if _rc>0 {
		parallel setclusters 8, force
	}
	capture noisily 												///
	synth_runner `var' 		`var'(2006) `var'(2007)					///
				`var'(2008) `var'(2009) `var'(2010) `var'(2011) 	///
				`var'(2012) `var'(2013) `y2014' `covVars',			///
				d(`treatVar') keep(SC_`var') margin(.05) `weights'	///
				replace `nested' `parallels'
	sctabout, outdta("`workingfolder'/`resultestsfile'.dta") greysig
	log close
	
	
	
	** Process results -- Generate estimation GRAPHS
	capture confirm file "`workingfolder'/`var'/SC_`var'.dta"	// Check if estimation finished successfully
	if _rc == 0 {	// Block for successfull estimation
		capture drop effect lead pre_rmspe post_rmspe
		merge 1:1 forestid year using "`workingfolder'/`var'/SC_`var'", nogen keep(match) keepusing(effect)		// Merge estimated forest-level estimations
		rename effect `var'_effect
								gen `var'_synth		= `var' - `var'_effect	// Calculate estimated forest-level counterfactual
		bysort treatment year: egen `var'_TM  		= mean(`var')		// Calculate avg. outcome for treat groups
		bysort treatment year: egen `var'_synth_TM	= mean(`var'_synth)	// Calculate avg. counterfactual for treat groups
		
		** Same graph formatted ourselves: define parameters for figures, then graph and export
			** -- Graph showing outcomes and synthetic for the whole treatment group
			if inlist("`var'", "conf30_aE200011", "conf50_aE200011") {
				local fid = 2
			}
			else {
				local fid = 1
			}
			qui su `var'_TM	if forestid == `fid', detail
			local 	ymax_TM	= r(max)										// Determine maximum outcome values for plotting
			qui su `var'_synth_TM	if forestid == `fid', detail
			local 	ymax = cond(`ymax_TM' > r(max), `ymax_TM', r(max))
			local	ymax = cond(`ymax' > .4, .8, .4)						// Local maximum outcome values
			qui su `var'_synth_TM	if forestid == `fid', detail
			local 	ymax = cond(r(max) > 1.2, r(max), .8)
			local 	step = round(`ymax'/6, 0.01)

			if "`var'"!="treecover" {
				twoway (line `var'_TM year      	if (forestid == `fid'),   lc(blue) lw(thick))	///
					   (line `var'_synth_TM year	if (forestid == `fid'),   lc(red) lp(dash)),	///
					   legend(label(1 "Treated") label(2 "Synthetic control") nobox region(lstyle(none)))	///
					   yscale(range(0(`step')`ymax')) ylabel( 0(`step')`ymax' ) ///
					   xline(`startYear', lc(black))							///
					   graphregion(color(white)) bgcolor( white )				///
					   name(tc_manual)
			}
			else {
				twoway (line treecover_TM year      	if (forestid == `fid'),   lc(blue) lw(thick))	///
					   (line treecover_synth_TM year	if (forestid == `fid'),   lc(red) lp(dash)),	///
					   legend(label(1 "Treated") label(2 "Synthetic control") nobox region(lstyle(none)))	///
					   yscale(range(5.25(0.1)5.45)) ylabel(5.25(0.1)5.45) ///
					   xline(2013, lc(black))							///
					   graphregion(color(white)) bgcolor( white )				///
					   name(tc_manual)
			}
			graph save tc_manual  	"`workingfolder'/`var'/TC_`var'_manual.gph", replace
			graph export          	"`workingfolder'/`var'/TC_`var'_manual.png", width(1500) replace
			graph export 			"`workingfolder'/`var'/TC_`var'_manual.eps", as(eps) replace

			** -- Graphs showing outcomes and synthetic at forest level
			local graphNames		""												// This macro will hold the graph names which will be combined
			forvalues forest = 1/12 { 		// Loop over forests to graph
				if `forest'==1 {
				    local legendtext `"label(1 "Treated") label(2 "Synthetic") region(lstyle(none))"'
				}
				else {
				    local legendtext "off"
				}
				
				twoway	(line `var' year if forestid == `forest', lc(blue) lw(thick) ) 	///
						(line `var'_synth year if forestid == `forest', lc(red) lp(dash) ), 	///
						legend(`legendtext') xline(`startYear', lc(black))		///
						graphregion(color(white)) bgcolor(white)				///
						title("`forest_name_`forest''") name(TC_`var'_`forest')
						
				graph save			"`workingfolder'/`var'/TC_`var'_`forest'", replace
				local graphNames	" `graphNames' TC_`var'_`forest' "		// Collect all graphs names together
			} // End of loop over forests to graph
			
			grc1leg `graphNames', rows(4) cols(3) iscale(0.25) ycommon ///
								graphregion(color(white)) plotregion(color(white)) ///
								legendfrom(TC_`var'_1)	
								
			graph save Graph				"`workingfolder'/`var'/TC_`var'_forests.gph", replace
			graph export					"`workingfolder'/`var'/TC_`var'_forests.png", width(2000) replace		
			graph export					"`workingfolder'/`var'/TC_`var'_forests.eps", as(eps) replace
			capture graph drop				_all
	}
	restore
}
