
* ------------------------------------------------------------------------------
*  Based on pre-set locals these code snippets generate the SCM estimates.
* ------------------------------------------------------------------------------
//do "$RepPack_doutility/sctabout.do"

local outCVars = "$gl_outCVars"
local covVars = "$gl_covVars"
local treat2015Vars = "$gl_treat2015Vars"
local noNestedVars = "$gl_noNestedVars"
local workingfolder = "$gl_workingfolder"
local resultestsfile = "$gl_resultestsfile"


** Estimate SCM for all outcome variable and generate the graphs
foreach var of local outCVars {
	** Determine parameters of SCM
	local startYear = 2013 + (strpos("`treat2015Vars'", "`var'")>0)
	local treatVar	"post`=`startYear'+1'Treatment"
	
	if `startYear'==2013{
		local y2014	""			// Do not fit on 2014 outcome (as pre-treatment period)
	}
	else {
		local y2014 "`var'(2014)" // Fit on 2014 outcome as well
	}
	
	** Determine if nested optimization over W and V should be used
	if strpos("`noNestedVars'","`var'")> 0 	local nested = ""		// simplified procedure
	if strpos("`noNestedVars'","`var'")==0 local nested = "nested"	// full nested optimization - nested

	
	
	** Prepare folders and files
	capture log close
	capture shell rmdir "`workingfolder'/`var'" /s /q
	capture shell mkdir "`workingfolder'/`var'"
	cd 					"`workingfolder'/`var'"
	log using 			"`workingfolder'/`var'/synth_res_`var'.txt", t replace
	
	** Main stimation and use sctabout to save results
	parallel initialize 8 , f 			// Parallel computing to shorten time especially with nested estimation
	capture noisily 												///
	synth_runner `var' 		`var'(2006) `var'(2007)					///
				`var'(2008) `var'(2009) `var'(2010) `var'(2011) 	///
				`var'(2012) `var'(2013) `y2014' `covVars',			///
				d(`treatVar') keep(SC_`var') margin(.05)   			///
				replace `nested' parallel deterministicoutput
	sctabout, outdta("`workingfolder'/`resultestsfile'.dta") greysig
	log close
	
	
	
	** Process results -- Generate estimation GRAPHS
	capture confirm file "`workingfolder'/`var'/SC_`var'.dta"	// Check if estimation finished successfully
	if _rc == 0 {	// Block for successfull estimation
		capture drop effect lead pre_rmspe post_rmspe
		merge 1:1 forestBlockID year using "`workingfolder'/`var'/SC_`var'", nogen keep(match) keepusing(effect)		// Merge estimated forest-level estimations
		rename effect `var'_effect
								gen `var'_synth		= `var' - `var'_effect	// Calculate estimated forest-level counterfactual
		bysort treatment year: egen `var'_TM  		= mean(`var')		// Calculate avg. outcome for treat groups
		bysort treatment year: egen `var'_synth_TM	= mean(`var'_synth)	// Calculate avg. counterfactual for treat groups
		
		** Same graph formatted ourselves: define parameters for figures, then graph and export
			** -- Graph showing outcomes and synthetic for the whole treatment group
			capture graph drop tc_manual
			qui su `var'_TM	if forestBlockID == 1056, detail
			local 	ymax_TM	= r(max)										// Determine maximum outcome values for plotting
			qui su `var'_synth_TM	if forestBlockID == 1056, detail
			local 	ymax = cond(`ymax_TM' > r(max), `ymax_TM', r(max))
			local	ymax = cond(`ymax' > .4, .8, .4)						// Local maximum outcome values
			qui su `var'_synth_TM	if forestBlockID == 1056, detail
			local 	ymax = cond(r(max) > 1.2, r(max), .8)
			local 	step = round(`ymax'/6, 0.01)

			twoway (line `var'_TM year      	if (forestBlockID == 1056),   lc(blue) lw(thick))	///
				   (line `var'_synth_TM year	if (forestBlockID == 1056),   lc(red) lp(dash)),	///
				   legend(label(1 "Treated") label(2 "Synthetic control") nobox region(lstyle(none)))	///
				   yscale(range(0(`step')`ymax')) ylabel( 0(`step')`ymax' ) ///
				   xline(`startYear', lc(black))							///
				   graphregion(color(white)) bgcolor( white )				///
				   name(tc_manual)
			graph save tc_manual  	"`workingfolder'/`var'/TC_`var'_manual.gph", replace
			graph export          	"`workingfolder'/`var'/TC_`var'_manual.png", width(1500) replace
			graph export			"`workingfolder'/`var'/TC_`var'_manual.eps", as(eps) replace
			capture graph drop				_all
	}
}