* **************************************************************************** *
* **************************************************************************** *
*           Combatting forest fires in the drylands of Sub-Saharan Africa:     *
*                Quas-experimental evidence from Burkina Faso                  *
* **************************************************************************** *
* **************************************************************************** *
/*
** PURPOSE:       Replication Package - Main Dofile

** OUTLINE:
 						  PART 1: Standardize settings and install packages
				          PART 2: Set globals for dynamic file paths
				          PART 3: Run do files to replicate the paper

** IDS VAR:       forerstid, forestBlockID, year

** WRITEN BY:
									Tung Nguyen Huy (nghuytungi@windowslive.com)
								

*/
* **************************************************************************** *


* **************************************************************************** *
* SET GLOBALS HERE:
* **************************************************************************** *
global GitHubFolder "C:/WBG/Rep-checks/Serge - Combatting forest fires in SSA v2/Forest Fire - Replication package"		// Folder to replication package
global live = 1													// Whether to run replication


	
* **************************************************************************** *
* PART 1:  Install required packages
* **************************************************************************** *
	
	clear all
	set more off
	cap log close
	set maxvar 32767
	set matsize 800

	*Install all packages that this project requires:

	local user_commands ietoolkit  spmap     shp2dta     mif2dta     matchit   ///
                       freqindex  outreg2     synth       npsynth    estout    ///
                       ivreg2     xtivreg2    ranktest    winsor2              ///
                       tabout     coefplot    expand  	excel2latex ereplace texsave 
   foreach command of local user_commands {
       cap which `command'
       if _rc == 111 {
           ssc install `command', all replace
       }
   }

    net install synth_runner, from(https://raw.github.com/bquistorff/synth_runner/master/) replace
	net install parallel, from(https://raw.github.com/gvegayon/parallel/stable/) replace
	net install grc1leg,from(http://www.stata.com/users/vwiggins/)

   *Standardize settings accross users
   ieboilstart, version(12.1) custom(set varabbrev on)
   
   
   
   
* **************************************************************************** *
* PART 2:  PREPARING FOLDER PATH GLOBALS AND GENERATE FOLDERS
* **************************************************************************** *

	* New User
	if c(username)== "wb532468"  {
	   global GitHub  "C:/WBG/Rep-checks/Serge - Combatting forest fires in SSA v2/Forest Fire - Replication package"
	}
	
	* Tung
	if c(username) == "u1273269" {
	    global GitHub  "C:/Users/u1273269/surfdrive/Working folders - PhD/Forest Fire - Replication package"
	}
	
	if "${GitHub}"=="" & "${GitHubFolder}"!="" {
		global GitHub "${GitHubFolder}"
	}
	
	gl RepPack				"$GitHub"
	
	* Replication Package Data file paths:
	gl RepPack_dt           "${RepPack}/Data"
	gl RepPack_dtInt        "${RepPack_dt}/Intermediate"
	gl RepPack_dtFin        "${RepPack_dt}/Final"
	
	* Replication Package Dofile file paths:
	gl RepPack_dofiles      "${RepPack}/Dofiles"
	gl RepPack_doConstruct  "${RepPack_dofiles}/Construct"
	gl RepPack_doAnalysis   "${RepPack_dofiles}/Analysis"
	gl RepPack_doutility   "${RepPack_doAnalysis}/utility"


	* Replication Package Output file paths:
	gl RepPack_Output       "${RepPack}/Output"
	gl RepPack_OutFigures   "${RepPack_Output}/Figures"
	gl RepPack_OutTables    "${RepPack_Output}/Results_Tables"
	gl RepPack_OutRaw		"${RepPack_Output}/_RawOutputs"
	
	* Replication Package Static Figures' path:
	gl RepPack_Static		"${RepPack}/StaticFigures"
	
	capture shell mkdir		"${RepPack_OutRaw}", public
	capture shell mkdir		"${RepPack_OutRaw}/Synthetic", public
	capture shell mkdir		"${RepPack_OutRaw}/Synthetic/fire_occurrence", public
	capture shell mkdir		"${RepPack_OutRaw}/Synthetic/fire_occurrence_robust", public
	capture shell mkdir		"${RepPack_OutRaw}/Synthetic/vegetation_cover", public
	capture shell mkdir		"${RepPack_OutRaw}/Synthetic/fire_occurrence_partitions", public
	
	capture shell mkdir 	"${RepPack_OutFigures}/Appendix", public
	capture shell mkdir 	"${RepPack_OutTables}/Appendix", public
	
	
	

* **************************************************************************** *
* PART 3: Run do files
* **************************************************************************** *

	* ----------------------------------------------------------------------------
	* Run ado files:
	quietly do "${RepPack}/ado/iebaltab_modified.ado"
	quietly do "${RepPack}/ado/sctabout.ado"

if ${live}==1 {

	* ----------------------------------------------------------------------------
	* Construct final data files:
	do "${RepPack_doConstruct}/ForestFire_Construct.do"
	
	* ----------------------------------------------------------------------------
	* Generate tables and figures:
	do "${RepPack_doAnalysis}/ForestFire_Analysis_Tables.do"
	do "${RepPack_doAnalysis}/ForestFire_Analysis_Figures.do"
	
}
	
	