

* Erase previously loaded version of the program
capture program drop sctabout

program defin sctabout

	version 14.2
	syntax, outdta(str) [tyear(integer -999) logfile(str) y(str) replace greysig]
	
	
	local goFlag 		=  0					// Flag to indicate whether all necessary info is available
	capture tempfile sctabout_alt_presctabout	// Temporary file to save file
	capture save	 `sctabout_alt_presctabout'
	
	di "SCTABOUT: Storing results from synth_runner."
	
	* ---------------------------------------------
	* Extract information from log or from return list of synth_runner
	if "`e(cmd)'" == "synth_runner" {			// From previous command
		di as result "sctabout called after synth_return"
		di as result "Extract information from synth_runner's return list"
		local depvar = e(depvar)
		if (e(treat_type)=="single_period") | ("`tyear'"=="-999"){
			local sct_tYear = e(trperiod)
		}
		else if ("`tyear'"!="-999"){
			local sct_tYear = `tYear'
		}
		else {
			di as error "sctabout: Only works with single treat period."
			error 197
		}
		
		
		matrix      sct_PE      = e(b)					// Store point estimates
		matrix      sct_PS      = e(pvals_std)			// Store significance-levels`'
		local       sct_M_size  = colsof(sct_PE)		// Number of point estimates
		qui xtset										// Extract post-treatment time periods
		qui levelsof `r(timevar)', local(timepers)	
		local sct_postYears		""
		foreach t of local timepers {				
			if `t'>= `sct_tYear'	local sct_postYears		"`sct_postYears' `t'"
		}
		local goFlag = 1	// All necessary information is available
	}
	else if "`logfile'"!="" {					// From log files
		di as result "Extracting information from log file"
		di as result "Logfile:    `logfile'"		
		di as result "Y:          `y'"
		di as result "TYear:      `tyear'"
		
				if "`logfile'"!=""   &   "`y'"!=""   &   `tyear'!=-999{
			local depvar        = "`y'"				// Store dependent variable
			local sct_tYear     = `tyear'			// Store treatment start
			local sct_regExpr   = "c[0-9] *\| * -?.[0-9]* *.[0-9]* *.[0-9]*"	// Regex string identifying estimations
																				// in the log-files produced by synth_runner



			clear
			local N             = 0					// Store the number of point estimates
			qui  gen  original  = ""
			capture file close logFile
			file open logFile using "`logfile'", read	// Open log-file to read line-by-line
			file read logFile line


			** Parse the log-file and extract estimation results
			while r(eof) == 0{									// Parse document
				if regexm(`"`line'"', "`sct_regExpr'") == 1{	// Check if line holds estimation results
				  local rawText       = subinstr("`line'", "|", "", 1)
				  local ++N
				  qui set obs `N'								// Store point estimates in memory
				  qui replace original= `"`rawText'"'     in `N'
				}

				file read logFile line
			}

			file close logFile

			qui split original,   gen(SCest) ignore("c") destring	// Separate point estimates from significance levels
			gen   period =        "c" + strofreal(SCest1)
			mkmat SCest2 SCest4,  matrix(sctA) rownames(period)		// Combine point estimates and p-values into matrix
			matrix colname sctA   = "y1" "pval"

			matrix sct_PE       = sctA[1...,1]'						// Store point estimates
			matrix sct_PS       = sctA[1...,2]'						// Store significance-levels
			local  sct_M_size   = colsof(sct_PE)					// Store umber of point estimates


			local goFlag        = 1
		}
	}
	else {					// Missing information
		di as error "sctabout: Missing information - either run after synth_runner or provide log file path." 
		error 197
	}
	
	* --------------------------------------------------------------------------
	* In case all necessary information is available, export results
	if  `goFlag' == 1 {
		
		** Check whether output file already exists
		capture confirm file "`outdta'"
		if _rc==0 & "`replace'"==""{		// File exists and no need to replace
			qui use "`outdta'", clear
			qui ds								// Verify identifying variables
			local varlist  "`r(varlist)'"	
			foreach var in year rowtype {	// Check whether it has been initialized (has year and rowtype variables)
				qui capture ds `var'
				if _rc!=0 {
					di "sctabout: Error - provied file is not suitable to store results"
					di "Please delete or rename `outdta' and re-run the sctabout"
				}
			}
			qui capture drop `depvar'
		}
		else {								// File did not exist or need to be replaced: initialize file
			quietly{
			clear
			set obs `=`sct_M_size'*2'
			gen year = `sct_tYear' + floor(abs(_n-1)/2)
			gen rowtype = mod(_n+1,2)
			lab def row_type 0 "Point estimate" 1 "Std. p-value"
			lab val rowtype row_type
			}
		}
		
		
		** Put estimates to result datafile
		qui gen `depvar' = ""
		forvalues i = 1/`sct_M_size' {
			quietly{
			local sig ""
			local currYear = `sct_tYear'-1+`i'
			if sct_PS[1,`i'] < .1	local sig "`sig'*"
			if sct_PS[1,`i'] < .05	local sig "`sig'*"
			if sct_PS[1,`i'] < .01	local sig "`sig'*"
			
			
			local effect 	= sct_PE[1,`i']
			local pval 		= sct_PS[1,`i']
			local fEffect :	display %4.3f `effect'
			local fPval : 	display %4.3f `pval'
			qui su rowtype if year==`currYear'
			if r(N)==0 {
				local NOBS = _N
				set obs `=`NOBS'+2'
				replace year = `currYear' if year==.
				replace rowtype = 0	in `=`NOBS'+1'
				replace rowtype = 1	in `=`NOBS'+2'
			}
			if "`sig'"=="" & "`greysig'"!="" {
				replace `depvar' = "\textcolor{gray}{`fEffect'`sig'}"		if year==`currYear' & rowtype==0
				replace `depvar' = "\textcolor{gray}{[`fPval']}"			if year==`currYear' & rowtype==1
			}
			else {
				replace `depvar' = "`fEffect'`sig'"		if year==`currYear' & rowtype==0
				replace `depvar' = "[`fPval']"			if year==`currYear' & rowtype==1
			}
			}
		}
		save "`outdta'", replace
	}
	else {	// GOFLAG: NOT ALL INPUTS HAVE BEEN RECEIVED
      di "ERROR: sctabout not called after `synth_runner` or not all parameters were specified"
	  error 197
	}
	
	
	
	
	
	** Clean work space and return to previous data
	capture use   `sctabout_alt_presctabout', clear
	capture erase `sctabout_alt_presctabout'
	macro drop _sct*
end
